==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/vpclattice/kotlin/inputs/ListenerRuleMatchHttpMatchPathMatchMatchArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.vpclattice.kotlin.inputs

import com.pulumi.aws.vpclattice.inputs.ListenerRuleMatchHttpMatchPathMatchMatchArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property exact Specifies an exact type match.
 * @property prefix Specifies a prefix type match. Matches the value with the prefix.
 */
public data class ListenerRuleMatchHttpMatchPathMatchMatchArgs(
    public val exact: Output<String>? = null,
    public val prefix: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.vpclattice.inputs.ListenerRuleMatchHttpMatchPathMatchMatchArgs> {
    override fun toJava():
        com.pulumi.aws.vpclattice.inputs.ListenerRuleMatchHttpMatchPathMatchMatchArgs =
        com.pulumi.aws.vpclattice.inputs.ListenerRuleMatchHttpMatchPathMatchMatchArgs.builder()
            .exact(exact?.applyValue({ args0 -> args0 }))
            .prefix(prefix?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ListenerRuleMatchHttpMatchPathMatchMatchArgs].
 */
@PulumiTagMarker
public class ListenerRuleMatchHttpMatchPathMatchMatchArgsBuilder internal constructor() {
    private var exact: Output<String>? = null

    private var prefix: Output<String>? = null

    /**
     * @param value Specifies an exact type match.
     */
    @JvmName("asboyigmchdmymcj")
    public suspend fun exact(`value`: Output<String>) {
        this.exact = value
    }

    /**
     * @param value Specifies a prefix type match. Matches the value with the prefix.
     */
    @JvmName("hnvtrrdxddoiuqsr")
    public suspend fun prefix(`value`: Output<String>) {
        this.prefix = value
    }

    /**
     * @param value Specifies an exact type match.
     */
    @JvmName("iclrmbbvxwvospil")
    public suspend fun exact(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.exact = mapped
    }

    /**
     * @param value Specifies a prefix type match. Matches the value with the prefix.
     */
    @JvmName("hkyhxytxwcbpsihh")
    public suspend fun prefix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.prefix = mapped
    }

    internal fun build(): ListenerRuleMatchHttpMatchPathMatchMatchArgs =
        ListenerRuleMatchHttpMatchPathMatchMatchArgs(
            exact = exact,
            prefix = prefix,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/vpclattice/kotlin/inputs/ListenerRuleMatchHttpMatchPathMatchMatchArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.vpclattice.kotlin.inputs

import com.pulumi.aws.vpclattice.inputs.ListenerRuleMatchHttpMatchPathMatchMatchArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property exact Specifies an exact type match.
 * @property prefix Specifies a prefix type match. Matches the value with the prefix.
 */
public data class ListenerRuleMatchHttpMatchPathMatchMatchArgs(
    public val exact: Output<String>? = null,
    public val prefix: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.vpclattice.inputs.ListenerRuleMatchHttpMatchPathMatchMatchArgs> {
    override fun toJava(): com.pulumi.aws.vpclattice.inputs.ListenerRuleMatchHttpMatchPathMatchMatchArgs =
        com.pulumi.aws.vpclattice.inputs.ListenerRuleMatchHttpMatchPathMatchMatchArgs.builder()
            .exact(exact?.applyValue({ args0 -> args0 }))
            .prefix(prefix?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ListenerRuleMatchHttpMatchPathMatchMatchArgs].
 */
@PulumiTagMarker
public class ListenerRuleMatchHttpMatchPathMatchMatchArgsBuilder internal constructor() {
    private var exact: Output<String>? = null

    private var prefix: Output<String>? = null

    /**
     * @param value Specifies an exact type match.
     */
    @JvmName("dctddmwhbfrexocy")
    public suspend fun exact(`value`: Output<String>) {
        this.exact = value
    }

    /**
     * @param value Specifies a prefix type match. Matches the value with the prefix.
     */
    @JvmName("lbtffsbawgqmejxg")
    public suspend fun prefix(`value`: Output<String>) {
        this.prefix = value
    }

    /**
     * @param value Specifies an exact type match.
     */
    @JvmName("vnrcghuwenvjgdwu")
    public suspend fun exact(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.exact = mapped
    }

    /**
     * @param value Specifies a prefix type match. Matches the value with the prefix.
     */
    @JvmName("kfifwtvbtmmtnrst")
    public suspend fun prefix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.prefix = mapped
    }

    internal fun build(): ListenerRuleMatchHttpMatchPathMatchMatchArgs =
        ListenerRuleMatchHttpMatchPathMatchMatchArgs(
            exact = exact,
            prefix = prefix,
        )
}
